***************
Neighbor degree
***************

.. automodule:: networkx.algorithms.neighbor_degree
.. autosummary::
   :toctree: generated/

Average neighbor degree
-----------------------   
.. autosummary::
   :toctree: generated/

   average_neighbor_degree
   average_neighbor_in_degree
   average_neighbor_out_degree

Average degree connectivity
---------------------------
.. autosummary::
   :toctree: generated/

   average_degree_connectivity
   average_in_degree_connectivity
   average_out_degree_connectivity
   k_nearest_neighbors
